==> appier_flutter-2.2.0.tar.gz: ios/Classes/SwiftAppierFlutterPlugin.swift <==
import Flutter

public class SwiftAppierFlutterPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(
      name: "appier_flutter",
      binaryMessenger: registrar.messenger()
    )
    let instance = SwiftAppierFlutterPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }
  
  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    guard let arguments = call.arguments as? [String: Any] else {
      result(FlutterError(
        code: "ILLEGAL_ARGUMENT",
        message: "\(call.method): arguments should be a dictionary",
        details: nil
      ))
      return
    }

    switch call.method {
    case "configure": AppierFlutter.shared.configure(arguments, result: result)
    case "setPushToken": AppierFlutter.shared.setPushToken(arguments, result: result)
    case "renewUserId": AppierFlutter.shared.renewUserId(arguments, result: result)
    case "setIdfaConsent": AppierFlutter.shared.setIDFAConsent(arguments, result: result)
    case "logEvent": AppierFlutter.shared.logEvent(arguments, result: result)
    case "setUniversalLinkDomains": AppierFlutter.shared.setUniversalLinkDomains(arguments, result: result)
    case "flush": AppierFlutter.shared.flush(arguments, result: result)
    case "setUserId": AppierFlutter.shared.setUserId(arguments, result: result)
    case "setName": AppierFlutter.shared.setName(arguments, result: result)
    case "setFirstName": AppierFlutter.shared.setFirstName(arguments, result: result)
    case "setLastName": AppierFlutter.shared.setLastName(arguments, result: result)
    case "setCity": AppierFlutter.shared.setCity(arguments, result: result)
    case "setEmail": AppierFlutter.shared.setEmail(arguments, result: result)
    case "setPhoneNumber": AppierFlutter.shared.setPhoneNumber(arguments, result: result)
    case "setDayOfBirth": AppierFlutter.shared.setDayOfBirth(arguments, result: result)
    case "setMonthOfBirth": AppierFlutter.shared.setMonthOfBirth(arguments, result: result)
    case "setYearOfBirth": AppierFlutter.shared.setYearOfBirth(arguments, result: result)
    case "setCustomKey": AppierFlutter.shared.setCustomKey(arguments, result: result)
    case "setAttributionWindow": AppierFlutter.shared.setAttributionWindow(arguments, result: result)
    case "setClickAttributionWindow": AppierFlutter.shared.setClickAttributionWindow(arguments, result: result)
    case "getRecommendation": AppierFlutter.shared.getRecommendation(arguments, result: result)
    case "logRecommendationClicked": AppierFlutter.shared.logRecommendationClicked(arguments, result: result)
    case "getRecommendationPopularTags": AppierFlutter.shared.getRecommendationPopularTags(arguments, result: result)
    case "getRecommendationProductToTags": AppierFlutter.shared.getRecommendationProductToTags(arguments, result: result)
    case "getRecommendationTagToTags": AppierFlutter.shared.getRecommendationTagToTags(arguments, result: result)
    case "getRecommendationUserToTags": AppierFlutter.shared.getRecommendationUserToTags(arguments, result: result)
    case "getRecommendationTagToProducts": AppierFlutter.shared.getRecommendationTagToProducts(arguments, result: result)
    case "hideInAppCampaigns": AppierFlutter.shared.hideInAppCampaigns(arguments, result: result)
    default: result(FlutterMethodNotImplemented)
    }
  }
}

==> appier_flutter-2.3.0.tar.gz: ios/Classes/SwiftAppierFlutterPlugin.swift <==
import Flutter

public class SwiftAppierFlutterPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(
      name: "appier_flutter",
      binaryMessenger: registrar.messenger()
    )
    let instance = SwiftAppierFlutterPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }
  
  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    guard let arguments = call.arguments as? [String: Any] else {
      result(FlutterError(
        code: "ILLEGAL_ARGUMENT",
        message: "\(call.method): arguments should be a dictionary",
        details: nil
      ))
      return
    }

    switch call.method {
    case "configure": AppierFlutter.shared.configure(arguments, result: result)
    case "setPushToken": AppierFlutter.shared.setPushToken(arguments, result: result)
    case "renewAppierId": AppierFlutter.shared.renewAppierId(arguments, result: result)
    case "getAppierId": AppierFlutter.shared.getAppierId(arguments, result: result)
    case "setIdfaConsent": AppierFlutter.shared.setIDFAConsent(arguments, result: result)
    case "logEvent": AppierFlutter.shared.logEvent(arguments, result: result)
    case "setUniversalLinkDomains": AppierFlutter.shared.setUniversalLinkDomains(arguments, result: result)
    case "flush": AppierFlutter.shared.flush(arguments, result: result)
    case "setUserId": AppierFlutter.shared.setUserId(arguments, result: result)
    case "setName": AppierFlutter.shared.setName(arguments, result: result)
    case "setFirstName": AppierFlutter.shared.setFirstName(arguments, result: result)
    case "setLastName": AppierFlutter.shared.setLastName(arguments, result: result)
    case "setCity": AppierFlutter.shared.setCity(arguments, result: result)
    case "setEmail": AppierFlutter.shared.setEmail(arguments, result: result)
    case "setPhoneNumber": AppierFlutter.shared.setPhoneNumber(arguments, result: result)
    case "setDayOfBirth": AppierFlutter.shared.setDayOfBirth(arguments, result: result)
    case "setMonthOfBirth": AppierFlutter.shared.setMonthOfBirth(arguments, result: result)
    case "setYearOfBirth": AppierFlutter.shared.setYearOfBirth(arguments, result: result)
    case "setCustomKey": AppierFlutter.shared.setCustomKey(arguments, result: result)
    case "setAttributionWindow": AppierFlutter.shared.setAttributionWindow(arguments, result: result)
    case "setClickAttributionWindow": AppierFlutter.shared.setClickAttributionWindow(arguments, result: result)
    case "getRecommendation": AppierFlutter.shared.getRecommendation(arguments, result: result)
    case "logRecommendationClicked": AppierFlutter.shared.logRecommendationClicked(arguments, result: result)
    case "getRecommendationPopularTags": AppierFlutter.shared.getRecommendationPopularTags(arguments, result: result)
    case "getRecommendationProductToTags": AppierFlutter.shared.getRecommendationProductToTags(arguments, result: result)
    case "getRecommendationTagToTags": AppierFlutter.shared.getRecommendationTagToTags(arguments, result: result)
    case "getRecommendationUserToTags": AppierFlutter.shared.getRecommendationUserToTags(arguments, result: result)
    case "getRecommendationTagToProducts": AppierFlutter.shared.getRecommendationTagToProducts(arguments, result: result)
    case "hideInAppCampaigns": AppierFlutter.shared.hideInAppCampaigns(arguments, result: result)
    default: result(FlutterMethodNotImplemented)
    }
  }
}
